unit CTWXDEF;
interface
uses WinProcs, WinTypes, Messages;
const

  PAGE_CLIENT  = 0;               { fill parent window client area }
  PAGE_FULL    = 1;               { fill the whole screen          }
  PAGE_EXACT   = 2;               { use passed coordinates         }

{ Page Window scaling types - fixed, proportionate, and isotropic }
  MM_FIXED   =  MM_ISOTROPIC;
  MM_PROPORT =  MM_ANISOTROPIC;
  MM_ISOTR   =  9;
  MM_PROPORT_FT = 10;
  MM_ISOTR_FT = 11;
{ coordinate types }

  CO_LOG  =0;
  CO_PHYS =1;
  CO_NORM =2;
  CO_DEV  =3;

{ Point search constants }

 FNP_X    = 0;   { nearest x }
 FNP_Y    = 1;   { nearest y }
 FNP_DIST = 2;   { shortest distance }

{ printing styles }

 PRT_FULL =   0;       { Pages and graphs are printed so that paper
                             is used maximally. Text is printed
                             proportionately to other objects }
 PRT_PROP =   1;       { Pages are printed so that paper
                             is used maximally. Graphs are printed
                             proportionately to page size.
                             Text is printed proportionately to other objects }

 PRT_EXACT =  2;   { physical size, font size in points are preserved }

{************************************************************************}
{ Graphical objects }
{************************************************************************}

    GO_PLOT   = 1;              { can be line, bars, scat, etc }
    GO_GROUP  = 2;              { can be stacked lines, bars   }
    GO_LEGEND = 3;
    GO_LINE   = 4;              { Straight line }
    GO_ARROW  = 5;              { Straight line with arrow }

    GO_LAST1  = 9;

    GO_AX     = 10;
    GO_LABELS = 11;
    GO_TEXT   = 12;
    GO_ARC    = 13;

    GO_LAST2  = 19;

{***********************************************************}

    GO_PIECHART = 20;
    GO_METAFILE = 21;
    GO_ELLIPSE  = 22;
    GO_BITMAP   = 23;
    GO_POLYGON  = 24;
    GO_RECT     = 25;
    GO_PIE      = 26;
    GO_DATACURSOR = 27;
    GO_PLOTSCALE  = 49;
    GOS_MAX  =   50;   { max value of statical graphical object }
    GO_USER  =  1000;

{ Line types - subtype field }

    LT_LINE   =   3;
    LT_LINEMARK = 4;
    LT_SCAT   =   5;
    LT_VBAR   =   6;
    LT_HBAR   =   7;
    LT_3DVBAR =   8;
    LT_3DHBAR =   9;
    LT_LAST   =   LT_3DHBAR;

{ types of group plots }

 GT_GROUPBARS   = 0;
 GT_DEEPBARS    = 1;
 GT_STACKEDBARS = 2;
 GT_FLOATBARS   = 3;
 GT_STACKEDLINES= 5;
 GT_HILOCLOSE   = 6;
 GT_ERRORBARS   = 7;

{ data cursor types }

 DC_VLINE  =  0;   { vertical line }
 DC_HLINE  =  1;   { horizontal line }
 DC_CROSS  =  2;   { crosshair }
 DC_BOX    =  3;   { square }

{************************************************************************}
{ Dynamic Graphical objects }
{************************************************************************}

    GO_DYN  = 100;         { First dynamic object }

 GOD_ALARMLINES = GO_DYN;      { alarm lines }
 GOD_ALARMMARKS = GO_DYN + 1;  { alarm marks (for bar graphs) }
 GOD_DYNGRID    = GO_DYN + 2;  { grid lines  }
 GOD_SCROLL     = GO_DYN + 3;  { scroll, sweep, scrolling bars, etc. }
 GOD_XYPLOT     = GO_DYN + 4;  { dynamic xy plot      }
 GOD_LABELS     = GO_DYN + 5;  { dynamic labels       }
 GOD_BARS       = GO_DYN + 6;  { dynamic bars         }
 GOD_TEXT       = GO_DYN + 7;  { dynamic text }
 GOD_MESSAGE    = GO_DYN + 8;  { message text }
 GOD_ANNUNC     = GO_DYN + 9;  { annunciator panel - compound object }
 GOD_METER      = GO_DYN + 10; { meter }
 GOD_CHCONTROL  = GO_DYN + 11; { child control }

 GOD_SUBT_SCLINE= 1;         { scrolling line subtype }
 GOD_SUBT_SCBAR = 2;         { scrolling bar  subtype }
 GOD_SUBT_SWLINE= 3;         { sweep line subtype }
 GOD_SUBT_LOGIC = 4;         { logic line subtype }
 GOD_SUBT_BAR   = 5;         { bar graph subtype  }
 GOD_SUBT_ALMTEXT =6;        { alarm text subtype }
 GOD_SUBT_STACKED =7;        { stacked line subtype }
 GOD_SUBT_TIME  =10;         { time subtype (for axes and labels) }

 ARROW_START =1;
 ARROW_END   =2;
 ARROW_BOTH  =3;

 MAX_ALMNAME =12;
 NALMLINES =5;

{ data reduction types }

 DC_SKIP    =0;
 DC_AVERAGE =1;
 DC_MAX     =2;
 DC_MIN     =3;

{ bitmap display modes }

 BM_ORIG     =0;
 BM_STRETCH  =1;

{ COLOR CODES }

    C_TRANSPARENT  = -1;
    C_BLACK        =  0;
    C_BLUE         =  1;
    C_GREEN        =  2;
    C_CYAN         =  3;
    C_RED          =  4;
    C_MAGENTA      =  5;
    C_BROWN        =  6;
    C_LIGHTGRAY    =  7;
    C_GRAY         =  8;
    C_LIGHTBLUE    =  9;
    C_LIGHTGREEN   = 10;
    C_LIGHTCYAN    = 11;
    C_LIGHTRED     = 12;
    C_LIGHTMAGENTA = 13;
    C_YELLOW       = 14;
    C_WHITE        = 15;

    C_PALEBLUE     = 16;
    C_PALEGREEN    = 17;
    C_MEDGRAY      = 18;
    C_OFFWHITE     = 19;

    NUMCOLS        = 20;

{************************************************************************}
{ Axis scaling types  }

    ST_LINEAR   = 0;
    ST_LOG      = 1;

{************************************************************************}
{ Grid types  }

    GRID_MAJOR  = 0;
    GRID_MINOR  = 1;
    GRID_ALL    = 2;

{************************************************************************}
{ Tick mark, bar, etc. position definitions: }

  POS_BELOW    = 0;
  POS_INSIDE   = POS_BELOW;
  POS_LEFT     = 1;
  POS_RIGHT    = 2;
  POS_MIDDLE   = 3;
  POS_ABOVE    = 4;
  POS_OUTSIDE  = POS_ABOVE;
  POS_INVISIBLE = 5;

  POS_BELOW_PLOT = 6;
  POS_ABOVE_PLOT = 7;
  POS_LEFT_PLOT  = 8;
  POS_RIGHT_PLOT = 9;

  TEXT_NORMAL    = 0;
  TEXT_VERTLEFT  = 900;
  TEXT_VERTRIGHT = 2700;

  TEXT_BOLD      = 1;           { can be ORed with each other }
  TEXT_ITAL      = 2;
  TEXT_UNDERLINE = 4;

{*********************************************************************}
{ last label indicators: }
{*********************************************************************}

  LL_ON   = 0;
  LL_OFF  = 1;
  LL_TEXT = 2;

  LABELLEN   = 42;        { maximal length of string label }
  LG_MAXLEN  = LABELLEN;  { maximal legend length }
  MAX_MESLEN = LABELLEN;  { 42 }
  MAX_MESNUM = 8 ;        { number of messages

{*********************************************************************}
{ Pie Chart Constants }
{*********************************************************************}

 PIE_NUM_NONE    = 0;
 PIE_NUM_PERC    = 1;
 PIE_NUM_VAL     = 2;
 PIE_NUM_BOTH    = 3;

 PIE_IN          = 0;
 PIE_OUT         = 1;

 PIE_2D          = 10;
 PIE_3D          = 11;

{*********************************************************************}
{ Numbers formats:                                                    }

    NF_DECIMAL    = 0;
    NF_SCIENTIFIC = 1;
    NF_ENG        = 2;
    NF_EXP        = 3;
    NF_G          = 4;

{**********************************************************************}
{ Intercept flags for auto axes.  }

    INTF_ZERO   = 0;       { use 0 for intercepts              }
    INTF_MIN    = 1;       { minimal values for both axes      }
    INTF_MAX    = 2;       { maximal values for both axes      }
    INTF_MINMAX = 3;       { min Y intercept for axis X, max for Y }
    INTF_MAXMIN = 4;       { max for X, min for Y                  }

{**********************************************************************}
{ Symbols (markers) types:                                             }

    MK_NONE          = 0;
    MK_X             = 1;
    MK_UPTRIANGLE    = 2;
    MK_DOWNTRIANGLE  = 3;
    MK_BOX           = 4;
    MK_PLUS          = 5;
    MK_ASTERISK      = 6;
    MK_DIAMOND       = 7;
    MK_CIRCLE        = 8;
    MK_DOT           = 9;

{*******************************************************************}
{ Marker and bar styles }

    MKS_FILLED     = 0;
    MKS_EMPTY      = 1;
    MKS_CDOT       = 2;

    BAR_FULL    = MKS_FILLED;
    BAR_HOLLOW  = MKS_EMPTY ;
    BAR_BORDER  = MKS_CDOT;

{**********************************************************************}
{ Autoscaling parameters: }

    AS_ROUNDCLOSE = 1;
    AS_ROUNDFAR   = 2;

{********************************************************************}
{ DSP constants (windows types)                                      }
{********************************************************************}

 DSPWIN_RECTANG = 0;
 DSPWIN_PARZEN  = 1;
 DSPWIN_HANNING = 2;
 DSPWIN_WELCH   = 3;
 DSPWIN_HAMMING = 4;
 DSPWIN_EXACTB  = 5;

{*************************************************************************}
{ orientation constants }

 OR_VERT  = 0;
 OR_HORZ  = 1;

{*************************************************************************}
{ raised rectangle constants }

 RC_FLAT     = 0;      { regular }
 RC_HIGH     = 1;
 RC_DEEP     = 2;
 RC_LOW      = 3;
 RC_SHALLOW  = 4;
 RC_3DBORDER = 5;


{*************************************************************************}
{ Metafile types }

 MF_WIN    = 0;    { Old Windows metafile    }
 MF_PL     = 1;    { Placeable Aldus metafile }
 MF_ENH    = 2;    { New enhanced Windows metafile }

{*************************************************************************}
{ placeable metafile header }



AXU_SEC    = 0;       { time units codes for time axes}
 AXU_MIN    = 1;
 AXU_HOUR   = 2;

{ staircase style}

 NO_STEP    =0;
 STEP_START =1;
 STEP_END   =2;

              { alarm types}
 ALM_OK    =0;
 ALM_SETP  =0;
 ALM_HIGH  =1;
 ALM_LOW   =2;
 ALM_HH    =3;
 ALM_LL    =4;
 ALM_RATE  =5;
 ALM_DEV   =6;
 ALM_FAIL  =7;

{ meter subtypes }
 GOD_SUBT_NEEDLE  = 0;       { needle meter  }
 GOD_SUBT_PIE     = 1;       { pie meter  }
 GOD_SUBT_ARC     = 2;       { arc meter  }

{********************************************************************}
{ Direction definitions                                              }
{********************************************************************}

 DYN_LEFT   = 0;       { scroll or move from right to left}
 DYN_RIGHT  = 1;
 DYN_UP     = 2;
 DYN_DOWN   = 3;

{************************************************************************}
{ Meter definitions******************************************************}
{************************************************************************}
{ needle types }

 NEEDLE_LINE     =  0;  { simple line}
 NEEDLE_THICK    =  1;  { thick lline with circle}
 NEEDLE_SHORTF   =  2;  { triangle with base at center - filled}
 NEEDLE_SHORTH   =  3;  { triangle with base at center - hollow}
 NEEDLE_LONGF    =  4;  { triangle with back plane - filled}
 NEEDLE_LONGH    =  5;  { triangle with back plane - hollow}

 MET_TICK_REG    = 0;
 MET_TICK_THICK  = 1;
 MET_TICK_TRIAG  = 2;

 MET_NOBORDER    = 0;
 MET_RECT        = 1;
 MET_CIRC        = 2;
 MET_RD_RECT     = 3;

{************************************************************************}
{ Dynamic label types ***************************************************}
{************************************************************************}
  DLB_NUMERIC  = 0;
  DLB_HMS      = 1;    { time format, hh:mm:ss. Prec ignored}
  DLB_HM       = 2;    { time format, hh:mm}
  DLB_MS       = 4;

{ CONTROL STYLES}
         { logic }
  BC_STYLE_PUSH      = 0;       { like standard push button}
  BC_STYLE_ONOFF     = 1;       { 2 state}
  BC_STYLE_XOR       = 2;       { radio button logic}
  BC_STYLE_PASSIVE   = 3;       { cannot be pressed}
         { appearance}
  BC_LOOK_LOW   = 0;            { standard pushbutton look}
  BC_LOOK_HIGH  = 1;            { "deep" pushbutton}
  BC_LOOK_RADIO = 2;            { standard radio button}
  BC_LOOK_CHECK = 3;            { "deep" check box}
  BC_LOOK_LED   = 4;            { LED}



 ST_LINEPLOT = 0;
 ST_BARGRAPH =1;
 ST_SCATTERPLOT =2;

 X_AXIS1 =0;
 Y_AXIS1 =1;
 X_AXIS2 =2;
 Y_AXIS2 =3;

 AXES1 =0;
 AXES2 =1;

 TITLE1 =0;
 TITLE2 =1;
 FOOTER =2;
 NUMAXES =4;
 NUMTITLES =3;

 SIMPLE_XY_DATA_TYPE =0;
 GROUP_DATA_TYPE     =1;
 PIECHART_DATA_TYPE  =2;

 SIMPLE_LEGEND =0;
 GROUP_LEGEND  =1;

 RTMETER_NEEDLE =0;
 RTMETER_ARC =1;
 RTMETER_PIE =2;

 CROSSHAIR_NONE =0;
 CROSSHAIR_GRAPHAREA= 1;
 CROSSHAIR_PLOTAREA =2;
 CROSSHAIR_SMALL =3;

 DATACURSOR_DISABLED= 0;
 DATACURSOR_LEFTBUTTON =1;
 DATACURSOR_RIGHTBUTTON= 2;

 SCROLLING_LINE_GRAPH =  0;
 SWEEP_GRAPH = 1;
 SCROLLING_BAR_GRAPH = 2;
 SCROLLING_STACKED_LINE_GRAPH= 3;
 SCROLLING_XY_GRAPH = 4;
 VARIABLE_SCROLLING_GRAPH= 5;

 LEGEND_BLACKTEXT =0;
 LEGEND_COLORTEXT =1;

 GRIDLINE_UPDATE_TIMER =0;
 GRIDLINE_UPDATE_EVERY =1;
 GRIDLINE_UPDATE_NEVER =2;

 ALARMLINE_UPDATE_TIMER =0;
 ALARMLINE_UPDATE_EVERY =1;
 ALARMLINE_UPDATE_NEVER =2;


 RGB_BLACK   =     $000000;
 RGB_BLUE    =     $800000;   //RGB (  0,0,128)
 RGB_GREEN   =     $008000;   //RGB (  0,128,  0)
 RGB_CYAN    =     $808000;   //RGB (  0,128,128)
 RGB_RED     =     $000080;   //RGB (128,  0,  0)
 RGB_MAGENTA =     $800080;   //RGB (128,  0,128)
 RGB_BROWN   =     $008080;   //RGB (128,128,  0)
 RGB_LIGHTGRAY =   $c0c0c0;   //RGB (192,192,192)
 RGB_GRAY       =  $808080;   //RGB (128,128,128)
 RGB_LIGHTBLUE  =  $ff0000;   //RGB (  0,  0,255)
 RGB_LIGHTGREEN =  $00ff00;   //RGB (  0,255,  0)
 RGB_LIGHTCYAN  =  $ffff00;   //RGB (  0,255,255)
 RGB_LIGHTRED   =  $0000ff;   //RGB (255,  0,  0)
 RGB_LIGHTMAGENTA= $ff00ff;   //RGB (255,  0,255)
 RGB_YELLOW   =    $00ffff;   //RGB (255,255,  0)
 RGB_WHITE    =    $ffffff;   //RGB (255,255,255)
               // for SVGA in 256 colors mode
 RGB_PALEBLUE =    $f0caa6;   //RGB (166,202,240)
 RGB_PALEGREEN=    $c0dcc0;   //RGB (192,220,192)
 RGB_MEDGRAY  =    $a4a0a0;   //RGB (160,160,164)
 RGB_OFFWHITE =    $f0f6ff;   //RGB (255,251,240)




IMPLEMENTATION

END.